@@ -8,7 +8,7 @@ use vars qw($VERSION);
 use Locale::Object::Country;
 use Locale::Object::DB;
 
-$VERSION = "0.21";
+$VERSION = "0.22";
 
 my $db = Locale::Object::DB->new();
 
@@ -122,17 +122,23 @@ sub name
 # Method for retrieving all countries in this continent.
 sub countries
 {
-    my $self = shift;
+  my $self = shift;
+   
+  # No name, no countries.
+  return unless $self->{_name};
     
-    # No name, no countries.
-    return unless $self->{_name};
-    
-    # Check for countries attribute. Set it if we don't have it.
-    _set_countries($self) unless $self->{_countries};
+  # Check for countries attribute. Set it if we don't have it.
+  _set_countries($self) unless $self->{_countries};
 
-    # Give an array if requested in array context, otherwise a reference.    
-    return @{$self->{_countries}} if wantarray;
+  # Give an array if requested in array context, otherwise a reference.    
+  if (wantarray)
+  {
+    return @{$self->{_countries}};
+  }
+  else
+  {
     return $self->{_countries};
+  }
 }
 
 # Private method to set an attribute with an array of objects for all countries in this continent.
@@ -173,7 +179,7 @@ Locale::Object::Continent - continent information objects
 
 =head1 VERSION
 
-0.21
+0.22
 
 =head1 DESCRIPTION
 
