@@ -2,43 +2,12 @@ package Locale::Object::Currency::Converter;
 
 use strict;
 use warnings::register;
-use Carp;
+use Carp qw(croak);
 use vars qw($VERSION);
 
 use Scalar::Util qw(looks_like_number);
 
-my ($use_xe, $xe_error, $use_yahoo, $yahoo_error);
-
-# Check if we have the two modules that actually do the work of conversions.
-eval {
-  require Finance::Currency::Convert::XE;
-};
-
-if ($@)
-{
-  $use_xe   = 0;
-  $xe_error = $@;
-}
-else
-{
-  $use_xe = 1;
-}
-
-eval {
-  require Finance::Currency::Convert::Yahoo;
-};
-
-if ($@)
-{
-  $use_yahoo   = 0;
-  $yahoo_error = $@;
-}
-else
-{
-  $use_yahoo = 1;
-}
-
-$VERSION = "0.12";
+$VERSION = "0.1";
 
 sub new
 {
@@ -101,38 +70,8 @@ sub service
   my $self = shift;
   my $service = shift;
   
-  # Be generous in what we accept.
-  $service = lc($service);
+  croak "Error: Values for service can be 'XE' or 'Yahoo'; you said $service." unless $service =~ /^Yahoo$|^XE$/;
     
-  if ($service eq 'xe')
-  {
-    # Check that we can use Finance::Currency::Convert::XE.
-    if ($use_xe == 1)
-    {
-      return $self;
-    }
-    else
-    {
-      carp "WARNING: Cannot set service to XE: $xe_error";
-    }
-  }
-  elsif ($service eq 'yahoo')
-  {
-    # Check that we can use Finance::Currency::Convert::Yahoo.
-    if ($use_yahoo == 1)
-    {
-      return $self;
-    }
-    else
-    {
-      carp "WARNING: Cannot set service to Yahoo: $yahoo_error";
-    }
-  }
-  else
-  {
-    carp "ERROR: Values for service can be 'XE' or 'Yahoo' (case-insensitive); you said '$service'.";
-  }
-  
   $self->{service} = $service;
 }
 
@@ -192,17 +131,13 @@ sub _yahoo
   my $self  = shift;
   my $value = shift;
   
+  use Finance::Currency::Convert::Yahoo;
+
   # We're not in a talkative mood.
   $Finance::Currency::Convert::Yahoo::CHAT = undef;
 
-  my $result;
-  
-  eval {
-    $result = Finance::Currency::Convert::Yahoo::convert($value,$self->{from}->code,$self->{to}->code);
-  };
-  
-  return "ERROR: $!" if $! ne '';
-  
+  my $result = Finance::Currency::Convert::Yahoo::convert($value,$self->{from}->code,$self->{to}->code);
+
   $result;
 }
 
@@ -211,23 +146,16 @@ sub _xe
 {
   my $self = shift;
   my $value = shift;
+  
+  use Finance::Currency::Convert::XE;
 
   my $xe = Finance::Currency::Convert::XE->new() or croak "Error: Couldn't create Finance::Currency::Convert::XE object: $!";
 
-  my $result;
-
-  eval
-  {
-    $result = $xe->convert(
-                           'source' => $self->{from}->code,
-                           'target' => $self->{to}->code,
-                           'value'  => $value
-                          );
-  };
-  
-  return "ERROR: $!" if $! ne '';
-  
-  $result;
+  return $xe->convert(
+                      'source' => $self->{from}->code,
+                      'target' => $self->{to}->code,
+                      'value'  => $value
+                     ) || croak $xe->error;
 }
 
 # Give the exchange rate of the currencies.
@@ -236,9 +164,9 @@ sub rate
   my $self = shift;
 
   # If there's no rate stored, set one.
-  $self->refresh unless $self->{_rate};
+  $self->refresh unless $self->{rate};
 
-  return $self->{_rate};
+  return $self->{rate};
 }
 
 # Give the time that the rate was stored.
@@ -246,9 +174,9 @@ sub timestamp
 {
   my $self = shift;
  
-  if ($self->{_timestamp})
+  if ($self->{timestamp})
   {
-    return $self->{_timestamp};
+    return $self->{timestamp};
   }
   else
   {
@@ -265,23 +193,10 @@ sub refresh
   my $rate = $self->convert(1);
 
   # Make a note of the rate and the time.
-  $self->{_rate}      = $rate;
-  $self->{_timestamp} = time;  
+  $self->{rate}      = $rate;
+  $self->{timestamp} = time;  
 }
 
-# Can you use Finance::Currency::Convert::XE?
-sub use_xe
-{
-  $use_xe;
-}
-
-# Can you use Finance::Currency::Convert::Yahoo?
-sub use_yahoo
-{
-  $use_yahoo;
-}
-
-
 1;
 
 __END__
@@ -292,7 +207,7 @@ Locale::Object::Currency::Converter - convert between currencies
 
 =head1 VERSION
 
-0.12
+0.1
 
 =head1 DESCRIPTION
 
@@ -317,9 +232,6 @@ C<Locale::Object::Currency::Converter> allows you to convert between values of c
     my $result    = $converter->convert(5);
     my $rate      = $converter->rate;
     my $timestamp = $converter->timestamp;
-
-    print $converter->use_xe;
-    print $converter->use_yahoo;
     
     $converter->from($eur);
     $converter->to($jpy);
@@ -339,18 +251,6 @@ This module requires L<Finance::Currency::Convert::XE> and L<Finance::Currency::
 
 Creates a new converter object. With no arguments, creates a blank object. Possible arguments are C<from>, C<to> and C<service>, all or none of which may be given. C<from> and C<to> must be L<Locale::Object::Currency> objects. C<service> must be one of either 'XE' or 'Yahoo', to specify the conversion should be done by L<http://xe.com/ucc/> or L<http://finance.yahoo.com/> respectively.
 
-=head2 C<use_xe()>
-
-    print $converter->use_xe;
-    
-Returns 1 or 0 depending on whether a C<use Finance::Currency::Convert::XE;> was successful. If 1, you can do conversions using the XE.com service.
-
-=head2 C<use_yahoo()>
-
-    print $converter->use_yahoo;
-    
-Returns 1 or 0 depending on whether a C<use Finance::Currency::Convert::Yahoo;> was successful. If 1, you can do conversions using the finance.yahoo.com service.
-
 =head2 C<from()>
 
     $converter->from($eur);
@@ -367,7 +267,7 @@ Sets a currency to do conversions to. Takes a L<Locale::Object::Currency> object
 
     $converter->service('Yahoo');
 
-Sets which currency conversion service to use. Depends on two other modules; see C<use_xe()> and C<use_yahoo()> above.
+Sets which currency conversion service to use.
 
 =head2 C<convert()>
 
